@@ -7,7 +7,7 @@ test_that("Output rf",{
   apartments_rf_model <- randomForest(m2.price ~ construction.year + surface + floor +
        no.rooms + district, data = apartments)
   explainer_rf <- explain(apartments_rf_model,
-       data = apartmentsTest[,2:6], y = apartmentsTest$m2.price)
+       data = apartmentsTest[,2:6], y = apartmentsTest$m2.price, verbose = FALSE)
   new_apartment <- apartmentsTest[1, ]
   wi_rf_2d <- ceteris_paribus_2d(explainer_rf, observation = new_apartment,
           variables = c("surface", "floor", "no.rooms"))
